## SgGo

一个对 RbCompiler 生成的 SG 文件可视化的工具。

### 安装

确保安装前有 Python 环境和 Pip 安装包。SgGo 安装包已打包到 Python PyPi 包管理服务，可以直接在线安装。

```
pip install SgGo
```

## 运行

使用可视化工具前，需要获取模型的可视化文件，`xxx_sg.json`，它的保存位置和 `xxx_sg.pbtxt` 一致，目前小网络生成的脚本中都会导出该文件，都保存在 `fpga` 目录中。

```
sg_go view xxx_sg.json --host 127.0.0.1 --port 5000
```

- `--host`: 指定 IP 地址，默认就是 `127.0.0.1`，如果就使用该地址，无需指定
- `--port`：指定端口号，默认 `5000`，一般服务器端的端口号都会被占用，我们需要使用大一点的端口号，如 `50008`。

本地使用时，运行以上命令即可在浏览器打开此链接 `127.0.0.1:5000`，即可打开模型结构图。

## windows 下服务器 ssh 隧道代理

在服务器运行此命令时，需要在本地浏览器打开，需要配置隧道代理，这里我们使用 MobaXterm 工具。


![img](./docs/imgs/1.png)

![img](./docs/imgs/2.png)

![img](./docs/imgs/3.png)

![img](./docs/imgs/4.png)

点击开始之后，关掉该窗口，在本地打开 `127.0.0.1:5005` 即可打开服务器上开启的可视化任务。

## 其他系统的用户请自己搜索 ssh 隧道代理设置，欢迎在此补充